@@ -3,4 +3,6 @@ from .models import *
 from .admin import *
 from .tests import *
 from .views import *
-from .signer import *
\ No newline at end of file
+from .signer import *
+from .decorators import *
+from .hash_for_file import *
\ No newline at end of file
